@@ -23,13 +23,17 @@
 #ifndef __GST_TOOL_H
 #define __GST_TOOL_H
 
+#include <gtk/gtk.h>
+
 G_BEGIN_DECLS
 
-#include <glade/glade.h>
-#include <gtk/gtk.h>
 #include <oobs/oobs.h>
 #include <gconf/gconf-client.h>
-#include "gst-types.h"
+
+typedef struct _GstTool      GstTool;
+typedef struct _GstToolClass GstToolClass;
+
+#include "gst-dialog.h"
 
 #define GST_TYPE_TOOL         (gst_tool_get_type ())
 #define GST_TOOL(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o),  GST_TYPE_TOOL, GstTool))
@@ -38,24 +42,26 @@ G_BEGIN_DECLS
 #define GST_IS_TOOL_CLASS(c)  (G_TYPE_CHECK_CLASS_TYPE ((c),     GST_TYPE_TOOL))
 #define GST_TOOL_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o),   GST_TYPE_TOOL, GstToolClass))
 
-typedef struct _GstTool      GstTool;
-typedef struct _GstToolClass GstToolClass;
-
 struct _GstTool {
 	GObject object;
 
 	gchar *name;
 	gchar *title;
 	gchar *icon;
+	gboolean lock_button;
 
 	OobsSession *session;
+	GPtrArray   *objects;
 	GConfClient *gconf_client;
 
-	char *glade_path;
-	char *glade_common_path;
+	char *ui_path;
+	char *common_ui_path;
 
 	GtkIconTheme *icon_theme;
 	GstDialog *main_dialog;
+	GtkWidget *configuration_changed_dialog;
+
+	time_t last_commit_time;
 
 	/* Progress report widgets */
 	GtkWidget *report_window;
@@ -82,7 +88,11 @@ GType        gst_tool_get_type            (void);
 void         gst_init                     (const gchar *app_name,
 					   int argc, char *argv [],
 					   GOptionEntry *entries);
-gboolean     gst_tool_is_authenticated    (GstTool *tool);
+
+void         gst_init_tool                (const char   *app_name,
+                                           int           argc,
+                                           char         *argv [],
+                                           GOptionEntry *entries);
 
 void         gst_tool_update_gui          (GstTool *tool);
 void         gst_tool_update_config       (GstTool *tool);
@@ -93,9 +103,26 @@ GtkIconTheme *gst_tool_get_icon_theme     (GstTool *tool);
 
 void         gst_tool_show_help       (GstTool*, gchar*);
 
-void         gst_tool_commit_async    (GstTool     *tool,
-				       OobsObject  *object,
-				       const gchar *message);
+OobsResult   gst_tool_commit          (GstTool *tool,
+				       OobsObject *object);
+
+void         gst_tool_commit_async    (GstTool             *tool,
+				       OobsObject          *object,
+				       const gchar         *message,
+				       OobsObjectAsyncFunc  func,
+				       gpointer             data);
+
+void         gst_tool_commit_error    (GstTool             *tool,
+                                       OobsResult           result);
+
+void         gst_tool_update_async    (GstTool             *tool);
+
+void         gst_tool_add_configuration_object (GstTool    *tool,
+						OobsObject *object);
+
+gboolean     gst_tool_authenticate    (GstTool *tool,
+				       OobsObject *object);
+
 
 G_END_DECLS
 
